==> qthello_1.0-1.tar.gz: qthello-1.0/src/mainwindow.cpp <==
#include <QMenu>
#include <QMenuBar>
#include <QAction>
#include <QMessageBox>
#include <QtGui>
#ifdef Q_WS_MAEMO_5
#   include <QtMaemo5/QMaemo5InformationBox>
#endif

#include "mainwindow.h"
#include "centralwidget.h"
#include "utils.h"

MainWindow::MainWindow(QWidget *parent)
    : QMainWindow(parent)
{
    QCoreApplication::setOrganizationName("XBASoft");
    QCoreApplication::setApplicationName("Qthello");

    setWindowTitle(tr("Qthello"));
    centralWdgt = new CentralWidget(this, reversiGame_);
    setCentralWidget(centralWdgt);
    createMenuToolbar();

#ifdef Q_WS_MAEMO_5
    setAttribute(Qt::WA_Maemo5AutoOrientation, true);
#endif

    connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(slotOrientationChanged()));
    slotNewGame();
}

MainWindow::~MainWindow()
{

}

void MainWindow::createMenuToolbar()
{
    QMenu *mn  = menuBar()->addMenu(tr("&Game"));
    QAction *a = mn->addAction(tr("&New game"));
    a->setShortcut(Qt::CTRL + Qt::Key_N);
    connect(a, SIGNAL(triggered()), this, SLOT(slotNewGame()));

    a = mn->addAction(tr("&Reset score"));
    connect(a, SIGNAL(triggered()), centralWdgt, SLOT(slotResetScore()));

    mn->addSeparator();

    a = mn->addAction(tr("E&xit"));
    a->setShortcut(Qt::ALT + Qt::Key_X);
    connect(a, SIGNAL(triggered()), this, SLOT(close()));

    mn = menuBar()->addMenu(tr("&Options"));
    a = mn->addAction(tr("&Options..."));
    connect(a, SIGNAL(triggered()), centralWdgt, SLOT(slotOptions()));

    mn = menuBar()->addMenu(tr("&Help"));
    a = mn->addAction(tr("&About..."));
    connect(a, SIGNAL(triggered()), this, SLOT(slotAbout()));
}

void MainWindow::slotNewGame()
{
    centralWdgt->newGame();
}

void MainWindow::slotOrientationChanged()
{
    centralWdgt->showInfoPanels();
}

void MainWindow::slotAbout()
{
    QMessageBox::about(this, tr("About Qthello"), tr("Othello/Reversi game\n\n"
                                "General programming - (c) 2010-2011 Vadim Khohlov <xvadima@ukr.net>\n\n"
                                "Images - GPE-Othello project (c) 2007 Joseph J. McCarthy <mccarthy@granular.che.pitt.edu>\n\n"
                                "AI Engine - KReversi project (c) 1997-2000, Mario Weilguni\n(c) 2004-2006, Inge Wallin\n(c) 2006, Dmitry Suzdalev"));
}

==> qthello_1.1.orig.tar.gz: qthello-1.1.orig/src/mainwindow.cpp <==
#include <QMenu>
#include <QMenuBar>
#include <QAction>
#include <QMessageBox>
#include <QtGui>
#ifdef Q_WS_MAEMO_5
#   include <QtMaemo5/QMaemo5InformationBox>
#endif

#include "mainwindow.h"
#include "centralwidget.h"
#include "utils.h"

MainWindow::MainWindow(QWidget *parent)
    : QMainWindow(parent)
{
    QCoreApplication::setOrganizationName("XBASoft");
    QCoreApplication::setApplicationName("Qthello");

    setWindowTitle(tr("Qthello"));
    centralWdgt = new CentralWidget(this, reversiGame_);
    setCentralWidget(centralWdgt);
    createMenuToolbar();

#ifdef Q_WS_MAEMO_5
    setAttribute(Qt::WA_Maemo5AutoOrientation, true);
#endif

    connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(slotOrientationChanged()));
    slotNewGame();
}

MainWindow::~MainWindow()
{

}

void MainWindow::createMenuToolbar()
{
    QMenu *mn  = menuBar()->addMenu(tr("&Game"));
    QAction *a = mn->addAction(tr("&New game"));
    a->setShortcut(Qt::CTRL + Qt::Key_N);
    connect(a, SIGNAL(triggered()), this, SLOT(slotNewGame()));

    a = mn->addAction(tr("&Reset score"));
    connect(a, SIGNAL(triggered()), centralWdgt, SLOT(slotResetScore()));

    mn->addSeparator();

    a = mn->addAction(tr("E&xit"));
    a->setShortcut(Qt::ALT + Qt::Key_X);
    connect(a, SIGNAL(triggered()), this, SLOT(close()));

    mn = menuBar()->addMenu(tr("&Options"));
    a = mn->addAction(tr("&Options..."));
    connect(a, SIGNAL(triggered()), centralWdgt, SLOT(slotOptions()));

    mn = menuBar()->addMenu(tr("&Help"));
    a = mn->addAction(tr("&About..."));
    connect(a, SIGNAL(triggered()), this, SLOT(slotAbout()));
}

void MainWindow::slotNewGame()
{
    centralWdgt->newGame();
}

void MainWindow::slotOrientationChanged()
{
    centralWdgt->showInfoPanels();
}

void MainWindow::slotAbout()
{
    QMessageBox::about(this, tr("About Qthello"), tr("Othello/Reversi game 1.0\n\n"
                                "General programming - (c) 2010-2011 Vadim Khohlov <xvadima@ukr.net>\n\n"
                                "Images - GPE-Othello project (c) 2007 Joseph J. McCarthy <mccarthy@granular.che.pitt.edu>\n\n"
                                "AI Engine - KReversi project (c) 1997-2000, Mario Weilguni\n(c) 2004-2006, Inge Wallin\n(c) 2006, Dmitry Suzdalev"));
}
